﻿using Controls02.Common;
using Controls02.Model;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Xml.Linq;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.UI.Popups;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;

// The Hub Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=286574

namespace Controls02
{
    /// <summary>
    /// A page that displays a grouped collection of items.
    /// </summary>
    public sealed partial class MainPage : Page
    {
        private NavigationHelper navigationHelper;
        private ObservableDictionary defaultViewModel = new ObservableDictionary();

        /// <summary>
        /// This can be changed to a strongly typed view model.
        /// </summary>
        public ObservableDictionary DefaultViewModel
        {
            get { return this.defaultViewModel; }
        }

        /// <summary>
        /// NavigationHelper is used on each page to aid in navigation and 
        /// process lifetime management
        /// </summary>
        public NavigationHelper NavigationHelper
        {
            get { return this.navigationHelper; }
        }

        public MainPage()
        {
            this.InitializeComponent();
            this.navigationHelper = new NavigationHelper(this);
            this.navigationHelper.LoadState += navigationHelper_LoadState;

            this.DefaultViewModel["IsLoading"] = true;

            // gestione del resize della finestra
            TheHub.SizeChanged += (sender, e) =>
            {
                if (e.NewSize.Width < 500)
                {
                    TheHub.Orientation = Orientation.Vertical;
                    HeroHubSection.Width = e.NewSize.Width;
                }
                else
                {
                    TheHub.Orientation = Orientation.Horizontal;
                    HeroHubSection.Width = (Window.Current.Bounds.Width * 2) / 3;
                }
            };
        }


        /// <summary>
        /// Populates the page with content passed during navigation.  Any saved state is also
        /// provided when recreating a page from a prior session.
        /// </summary>
        /// <param name="sender">
        /// The source of the event; typically <see cref="NavigationHelper"/>
        /// </param>
        /// <param name="e">Event data that provides both the navigation parameter passed to
        /// <see cref="Frame.Navigate(Type, Object)"/> when this page was initially requested and
        /// a dictionary of state preserved by this page during an earlier
        /// session.  The state will be null the first time a page is visited.</param>
        private async void navigationHelper_LoadState(object sender, LoadStateEventArgs e)
        {
            var client = new HttpClient();
            var text = await client.GetStringAsync("http://www.bing.com/HPImageArchive.aspx?format=xml&idx=0&n=15&mkt=en-US");

            var doc = XDocument.Parse(text);

            var group = new GroupContent();

            var images = doc.Descendants("image").Select(x => new Content
            {
                Url = "http://www.bing.com/" + x.Element("url").Value,
                Title = x.Element("copyright").Value,
            });

            foreach (var item in images)
            {
                group.Add(item);
            }

            // binding
            this.DefaultViewModel["FirstImage"] = group[0];
            this.DefaultViewModel["Images"] = group.Skip(1);

            this.DefaultViewModel["FeaturedImage"] = group[5];

            // semantic zoom
            this.DefaultViewModel["Groups"] = TheHub.Sections.Select(x => x.Header).Where(x => x != null);

            this.DefaultViewModel["IsLoading"] = false;
        }

        #region NavigationHelper registration

        /// The methods provided in this section are simply used to allow
        /// NavigationHelper to respond to the page's navigation methods.
        /// 
        /// Page specific logic should be placed in event handlers for the  
        /// <see cref="GridCS.Common.NavigationHelper.LoadState"/>
        /// and <see cref="GridCS.Common.NavigationHelper.SaveState"/>.
        /// The navigation parameter is available in the LoadState method 
        /// in addition to page state preserved during an earlier session.

        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            navigationHelper.OnNavigatedTo(e);
        }

        protected override void OnNavigatedFrom(NavigationEventArgs e)
        {
            navigationHelper.OnNavigatedFrom(e);
        }

        #endregion

        private void SearchBox_SuggestionsRequested(SearchBox sender, SearchBoxSuggestionsRequestedEventArgs args)
        {
            if (args.QueryText.Length > 3)
            {
                for (int i = 0; i < 5; i++)
                {
                    args.Request.SearchSuggestionCollection.AppendQuerySuggestion(args.QueryText + " " + i.ToString());
                }
            }
        }

        private async void SearchBox_QuerySubmitted(SearchBox sender, SearchBoxQuerySubmittedEventArgs args)
        {
            await new MessageDialog("Hai cercato: " + args.QueryText).ShowAsync();
        }
    }
}
